Your privacy is important. I, Josh Sunnex, am committed to being transparent and open. This Privacy Policy
explains generally how I receive information about you, and what I do with that information once I have it.

## Definition of “personal information”?

For me, “personal information” means information which identifies you, like your name or email address.

Any information that falls outside of this is “non-personal information”.

If I store your personal information with information that is non-personal, I will consider the combination
as personal information. If I remove all personal information from a set of data then the remaining is
non-personal information.

## How do I learn information about you?

I learn information about you when:

 - You give it to me directly (e.g., when you choose to send me logs in the forums)
 - I collect it automatically through my software and services (e.g., when your Unmanic installation registers with the Unmanic  site, or when your Unmanic installation connects with my servers to download plugins)
 - You visit the Unmanic website

## What do I do with your information once I have it?

Generally, I use your information to help me provide and improve my software and services for you (e.g., I
use a log you send me to figure out why Unmanic isn’t working correctly, or I determine how many active
users are using Unmanic and on what platforms it is being used in order to determine how to allocate
resources per platform).

## When do I share your information with others?

The information that you provide me is intended for me alone. The only time I will share this information
with a third party is when I have asked and received your permission to share it.

## How do I store and protect your personal information?

I am committed to protecting your personal information once I have it. All information will be securely
stored using best practices. Despite these efforts, if I learn of a security breach, I’ll notify you so
that you can take appropriate protective steps.

## What if I change this privacy policy?

I may need to change this policy. Updates to the policy will be amended here with a changelog at the
bottom.
If the changes are substantive, I will announce the update through social media channels. Your continued
use of my products or services after the effective date of such changes constitutes your acceptance of such
changes. To make your review more convenient, I will post an effective date at the top of the page.

---

<div style="text-align: right">
<b>Effective Date:</b>
21 March, 2021
</div>

---

## Changelog

**21 March, 2021**
 - Initial policy
